AtResponse

Enum AtResponse 

pub enum AtResponse {
    InformationResponse {
        param: String,
        response: AtValue,
    },
    ResultCode(AtResultCode),
    Unknown(String),
}
One of possibly many response lines to an AT command.

One AtResponse always corresponds to one line of text.

Variants



InformationResponse

An information response issued as a result of a command.

Corresponds to ‘: ’.

Fields

param: String
response: AtValue


ResultCode(AtResultCode)

An AT result code, indicating the completion of a command.



Unknown(String)

Some other unknown response.

Implementations

Source

impl AtResponse

enum Variant Predicates

pub fn is_information_response(&self) -> bool

Is this AtResponse a InformationResponse?

pub fn is_result_code(&self) -> bool

Is this AtResponse a ResultCode?

pub fn is_unknown(&self) -> bool

Is this AtResponse a Unknown?