AtResultCode

Enum AtResultCode 

pub enum AtResultCode {
Show 14 variants Ok, Connect, Ring, NoCarrier, Error, CmeError(u32), CmsError(CmsError), CmsErrorString(String), CmsErrorUnknown(u32), NoDialtone, Busy, NoAnswer, CommandNotSupported, TooManyParameters,
}
An AT result code, which indicates the completion of a command.

Variants



Ok

Command executed without failure.



Connect

Connection established.



Ring

Incoming call.



NoCarrier

Connection terminated.



Error

Generic error (rather unhelpful).



CmeError(u32)

CME error (= generic error), with annoyingly opaque error code (will be fixed).

There is a list of CME errors that I should really get around to making into an enum. However, that’s annoying, so I haven’t done it yet.



CmsError(CmsError)

Typed CMS error (= SMS-related error) that uses one of the available error codes.



CmsErrorString(String)

CMS error given as string, because of modem configuration.

There’s probably some way to get modems to report errors as a numeric error code, so you can make use of the enum. However, I don’t know of one.



CmsErrorUnknown(u32)

Unknown CMS error code.



NoDialtone

No dialtone.



Busy

Recipient busy.



NoAnswer

No answer.



CommandNotSupported

Command not supported.



TooManyParameters

Too many parameters.

Implementations

Source

impl AtResultCode

enum Variant Predicates

pub fn is_ok(&self) -> bool

Is this AtResultCode a Ok?

pub fn is_connect(&self) -> bool

Is this AtResultCode a Connect?

pub fn is_ring(&self) -> bool

Is this AtResultCode a Ring?

pub fn is_no_carrier(&self) -> bool

Is this AtResultCode a NoCarrier?

pub fn is_error(&self) -> bool

Is this AtResultCode a Error?

pub fn is_cme_error(&self) -> bool

Is this AtResultCode a CmeError?

pub fn is_cms_error(&self) -> bool

Is this AtResultCode a CmsError?

pub fn is_cms_error_string(&self) -> bool

Is this AtResultCode a CmsErrorString?

pub fn is_cms_error_unknown(&self) -> bool

Is this AtResultCode a CmsErrorUnknown?

pub fn is_no_dialtone(&self) -> bool

Is this AtResultCode a NoDialtone?

pub fn is_busy(&self) -> bool

Is this AtResultCode a Busy?

pub fn is_no_answer(&self) -> bool

Is this AtResultCode a NoAnswer?

pub fn is_command_not_supported(&self) -> bool

Is this AtResultCode a CommandNotSupported?

pub fn is_too_many_parameters(&self) -> bool

Is this AtResultCode a TooManyParameters?