AtValue

Enum AtValue 

pub enum AtValue {
    String(String),
    Integer(u32),
    Range((u32, u32)),
    Unknown(String),
    Empty,
    BracketedArray(Vec<AtValue>),
    Array(Vec<AtValue>),
}
Any of a set of types used in AT commands.

Variants



String(String)

A string-type value - text surrounded by “quotation marks”.



Integer(u32)

An integer.



Range((u32, u32))

A range of integers.



Unknown(String)

Some untyped value - usually ‘bareword’ strings, i.e. strings that aren’t surrounded in “quotation marks”.



Empty

An empty value, corresponding to nothing at all.



BracketedArray(Vec<AtValue>)

A bracketed array.



Array(Vec<AtValue>)

A non-bracketed array.

Implementations

Source

impl AtValue

enum Variant Predicates

pub fn is_string(&self) -> bool

Is this AtValue a String?

pub fn is_integer(&self) -> bool

Is this AtValue a Integer?

pub fn is_range(&self) -> bool

Is this AtValue a Range?

pub fn is_unknown(&self) -> bool

Is this AtValue a Unknown?

pub fn is_empty(&self) -> bool

Is this AtValue a Empty?

pub fn is_bracketed_array(&self) -> bool

Is this AtValue a BracketedArray?

pub fn is_array(&self) -> bool

Is this AtValue a Array?

Source

impl AtValue

This impl block provides methods to extract various types out of an AtValue. If the value is not of the desired type, HuaweiError::TypeMismatch is returned.

  • as_x methods take self, and return either the type or an error.
  • get_x methods take &self, and return a & reference.
  • get_x_mut methods take &mut self, and return a &mut reference.