pub struct AtResponsePacket {
pub responses: Vec<AtResponse>,
pub status: AtResultCode,
}Expand description
The complete set of responses to an issued AT command.
Fields
responses: Vec<AtResponse>The various AtResponses issued.
Note that this will only contain ‘expected’ InformationResponses,
as well as any Unknown responses. ‘Expected’ values are values
that were expected as a result of the command issued - for more
information, see the AtCommand documentation.
status: AtResultCodeThe final result code for this command.
Implementations
Sourceimpl AtResponsePacket
impl AtResponsePacket
Sourcepub fn extract_named_response_opt(
&self,
resp: &str,
) -> HuaweiResult<Option<&AtValue>>
pub fn extract_named_response_opt( &self, resp: &str, ) -> HuaweiResult<Option<&AtValue>>
Extracts the value of an InformationResponse that has a given resp
as its param, if such a response exists.
Also invokes self.assert_ok()?, to verify that the response was successful.
Sourcepub fn extract_named_response(&self, resp: &str) -> HuaweiResult<&AtValue>
pub fn extract_named_response(&self, resp: &str) -> HuaweiResult<&AtValue>
Like extract_named_response_opt, but fails with a HuaweiError::ExpectedResponse if the
named response doesn’t actually exist.
Sourcepub fn assert_ok(&self) -> HuaweiResult<()>
pub fn assert_ok(&self) -> HuaweiResult<()>
Returns HuaweiError::AtError(self.status.clone()) if the status code was not Ok.