#[repr(u8)]pub enum ModemOperationMode {
MinimumFunctionality = 0,
OnlineMode = 1,
OfflineMode = 4,
FtmMode = 5,
Restart = 6,
DisableRf = 7,
}Expand description
The current modem operation mode (from AT+CFUN).
Presumably, this is useful for power saving or something. Note that not all state transitions are necessarily allowed by the modem - in particular, it looks like going from offline to online is not allowed on some modems, presumably requiring a restart. Consulting your modem manual may be advisable.
Variants
MinimumFunctionality = 0
Minimum functionality possible.
In this mode, RF is disabled, but the SIM card is still powered.
OnlineMode = 1
Online mode.
OfflineMode = 4
Offline mode.
FtmMode = 5
FTM mode.
I have zero clue what this is.
Restart = 6
Restart the modem.
DisableRf = 7
Disable RF.