#[repr(u8)]pub enum RegistrationState {
NotRegisteredAndDisabled = 0,
RegisteredHome = 1,
NotRegisteredSearching = 2,
RegistrationDenied = 3,
Unknown = 4,
RegisteredRoaming = 5,
}Expand description
The current registration state of the modem (from AT+CREG).
Modems have to be ‘registered’ (i.e. connected to) a given cellular network to be able to do anything useful (text, call, etc.). Therefore, checking the registration state can be useful to figure out why your modem isn’t working.
Variants
NotRegisteredAndDisabled = 0
Not registered, and not searching for a new operator at present.
RegisteredHome = 1
Registered, and on our ‘home’ network (i.e. not roaming)
NotRegisteredSearching = 2
Not registered, and searching for a new operator.
RegistrationDenied = 3
Registration denied.
Unknown = 4
Registration state unknown.
RegisteredRoaming = 5
Reigstered, and on a ‘roaming’ network.
Implementations
Sourceimpl RegistrationState
impl RegistrationState
Sourcepub fn is_registered(&self) -> bool
pub fn is_registered(&self) -> bool
If the RegistrationState is either RegisteredHome or RegisteredRoaming, returns
true. Otherwise, returns false.