SignalQuality

Struct SignalQuality 

pub struct SignalQuality {
    pub rssi: u32,
    pub ber: u32,
}
Signal quality, as returned from the modem (AT+CSQ).

The exact values of this struct may vary based on your modem type. Consult your modem manual for more information.

Fields

rssi: u32

Recieved Signal Strength Indication (RSSI) value.

At least on some modems, this value may have the following meanings:

  • 0 → less than or equal to -113 dBm
  • 1 → -111 dBm
  • 2-30 → -109 to -53 dBm
  • 31 → greater than or equal to -51 dBm
  • 99 → unknown or undetectable.
ber: u32

Channel bit error rate, in percent.

On some modems, this is permanently 99 (i.e. unsupported).