#[repr(u8)]pub enum NewMessageNotification {
BufferInMe = 0,
SendDirectlyOrDiscard = 1,
SendDirectlyOrBuffer = 2,
}Expand description
Controls whether to notify the TE about new messages (from AT+CNMI).
Variants
BufferInMe = 0
Buffer new message indications in the ME, overwriting old indications if necessary.
SendDirectlyOrDiscard = 1
Send SMS-DELIVER indications to the TE, discarding them if they cannot be sent (for example, when in online data mode)
SendDirectlyOrBuffer = 2
Send SMS-DELIVER indications to the TE, buffering them and sending them later if they cannot be sent.
If you’re aiming to use new message notification, this is probably what you want.