#[repr(u8)]pub enum NewMessageStorage {
RouteNothing = 0,
StoreAndNotify = 1,
SendDirectly = 2,
StoreAndDiscardNotification = 3,
}Expand description
Controls how new messages are saved, and how indications are sent to the TE (from AT+CNMI).
Variants
RouteNothing = 0
Do not route any SMS-DELIVER indications to the TE.
StoreAndNotify = 1
Store SMS-DELIVER indications on the MT, and send a +CMTI: <mem>,<index> URC to
the TE.
If you’re aiming to use new message notification, this is probably what you want (and is
the only thing that has really been tested apart from RouteNothing).
SendDirectly = 2
Directly forward the SMS-DELIVER indication to the TE, sending a +CMT: [<reserved>],<length><CR><LF><pdu> URC to the TE.
StoreAndDiscardNotification = 3
Store SMS-DELIVER indications on the MT, but don’t notify the TE.