pub enum CmsError {
Show 45 variants
UnassignedNumber = 1,
OperatorDeterminedBarring = 8,
CallBarred = 10,
TransferRejected = 21,
DestinationOutOfService = 27,
UnidentifiedSubscriber = 28,
FacilityRejected = 29,
UnknownSubscriber = 30,
NetworkOutOfOrder = 38,
TemporaryFailure = 41,
Congestion = 42,
ResourcesUnavailable = 47,
NotSubscribed = 50,
NotImplemented = 69,
InvalidReferenceValue = 81,
InvalidMessage = 95,
InvalidMandatoryInformation = 96,
NonexistentMessageType = 97,
IncompatibleMessage = 98,
NonexistentInformationElement = 99,
ProtocolError = 111,
InternetworkingError = 127,
MeFailure = 300,
SmsServiceReserved = 301,
NotAllowed = 302,
NotSupported = 303,
InvalidPduModeParameter = 304,
InvalidTextModeParameter = 305,
SimNotInserted = 310,
SimPinRequired = 311,
PhSimPinRequired = 312,
SimFailure = 313,
SimBusy = 314,
SimWrong = 315,
SimPukRequired = 316,
SimPin2Required = 317,
SimPuk2Required = 318,
MemoryFailure = 320,
InvalidMemoryIndex = 321,
MemoryFull = 322,
SmscAddressUnknown = 330,
NoNetworkService = 331,
NetworkTimeout = 332,
NoCnmaAcknowledgementExpected = 340,
UnknownError = 500,
}Expand description
A CMS (SMS-related) error code.
I can’t be bothered to write out all the error code meanings twice. If you hit the [src]
button in rustdoc, it’ll take you to the definition of this enum, where the meanings of each
variant are annotated with #[fail(display)] attributes.
Obviously, this means that this enum has a rather useful Display implementation.
Variants
UnassignedNumber = 1
OperatorDeterminedBarring = 8
CallBarred = 10
TransferRejected = 21
DestinationOutOfService = 27
UnidentifiedSubscriber = 28
FacilityRejected = 29
UnknownSubscriber = 30
NetworkOutOfOrder = 38
TemporaryFailure = 41
Congestion = 42
NotSubscribed = 50
NotImplemented = 69
InvalidReferenceValue = 81
InvalidMessage = 95
InvalidMandatoryInformation = 96
NonexistentMessageType = 97
IncompatibleMessage = 98
NonexistentInformationElement = 99
ProtocolError = 111
InternetworkingError = 127
MeFailure = 300
SmsServiceReserved = 301
NotAllowed = 302
NotSupported = 303
InvalidPduModeParameter = 304
InvalidTextModeParameter = 305
SimNotInserted = 310
SimPinRequired = 311
PhSimPinRequired = 312
SimFailure = 313
SimBusy = 314
SimWrong = 315
SimPukRequired = 316
SimPin2Required = 317
SimPuk2Required = 318
MemoryFailure = 320
InvalidMemoryIndex = 321
MemoryFull = 322
SmscAddressUnknown = 330
NoNetworkService = 331
NetworkTimeout = 332
NoCnmaAcknowledgementExpected = 340
UnknownError = 500