pub enum CommandError<T>where
T: Fail,{
Command(T),
Huawei(HuaweiError),
}Expand description
An error either raised by a command implementation, or by the library itself.
Variants
Command(T)
An error in the implementation of some generic command.
Huawei(HuaweiError)
An error raised by the library itself.