pub struct DecodedMessage {
pub text: String,
pub udh: Option<UserDataHeader>,
}Expand description
A decoded text mesasge, with optional user data header.
Fields
text: StringDecoded text.
udh: Option<UserDataHeader>User data header. You’ll want this to check if the message is concatenated, i.e. is part of a multi-part series.