#[repr(u8)]pub enum TypeOfNumber {
Unknown = 0,
International = 16,
National = 32,
Special = 48,
Gsm = 80,
Short = 96,
Reserved = 112,
}Expand description
Type of number value - used as part of phone numbers to indicate whether the number is international, alphanumeric, etc.
Variants
Unknown = 0
Unknown number type (‘let the network handle it please’).
International = 16
International (i.e. starting with +). This is probably what you want when sending messages.
National = 32
National number - no prefix or suffix added.
Special = 48
Special number - you can’t send messages with this type.
Gsm = 80
Alphanumeric number - i.e. this isn’t a phone number, it’s actually some text that indicates who the sender is (e.g. when banks/other companies send you SMSes).
You can’t send messages with this type.
Short = 96
Short number (not in use).
Reserved = 112
Reserved (not in use).