AtCommand

Enum AtCommand 

pub enum AtCommand {
    Equals {
        param: String,
        value: AtValue,
    },
    Execute {
        command: String,
    },
    Read {
        param: String,
    },
    Test {
        param: String,
    },
    Basic {
        command: String,
        number: Option<usize>,
    },
    Text {
        text: String,
        expected: Vec<String>,
    },
}
An AT command.

Variants



Equals

Either execute a non-basic command named param with value as argument, or set the current value of param to value.

Corresponds to AT<param>=<value>.

Fields

param: String
value: AtValue


Execute

Execute a non-basic command, with the name of command.

Corresponds to AT<command>.

Fields

command: String


Read

Read the current value of param.

Corresponds to AT<param>?.

Fields

param: String


Test

Return the available value range of param.

Corresponds to `AT=?’.

Fields

param: String


Basic

Execute a basic command, where command indicates a single letter (A-Z) or the & symbol and a single letter, with an optional number parameter.

Corresponds to AT<command>[<number>].

Fields

command: String
number: Option<usize>


Text

Just send some raw text.

Fields

text: String
expected: Vec<String>

The set of ‘expected’ InformationResponses to this command.

Implementations

Source

impl AtCommand

pub fn expected(&self) -> Vec<String>

Get the set of ‘expected’ InformationResponses for this command.

This is used by the library to filter out URCs (Unsolicited Response Codes) - basically, commands only get InformationResponses that match their expected() array, so we can filter all of the other responses out and assume that they’re URCs.

  • For Equals, Read, and Test, this is the value of vec![param].
  • For Execute and Basic, this is the value of vec![command].
  • For Text, this is the value of expected.
Source

impl AtCommand

enum Variant Predicates

pub fn is_equals(&self) -> bool

Is this AtCommand a Equals?

pub fn is_execute(&self) -> bool

Is this AtCommand a Execute?

pub fn is_read(&self) -> bool

Is this AtCommand a Read?

pub fn is_test(&self) -> bool

Is this AtCommand a Test?

pub fn is_basic(&self) -> bool

Is this AtCommand a Basic?

pub fn is_text(&self) -> bool

Is this AtCommand a Text?