pub enum AtResultCode {
}Expand description
An AT result code, which indicates the completion of a command.
Variants
Ok
Command executed without failure.
Connect
Connection established.
Ring
Incoming call.
NoCarrier
Connection terminated.
Error
Generic error (rather unhelpful).
CmeError(u32)
CME error (= generic error), with annoyingly opaque error code (will be fixed).
There is a list of CME errors that I should really get around to
making into an enum. However, that’s annoying, so I haven’t done
it yet.
CmsError(CmsError)
Typed CMS error (= SMS-related error) that uses one of the available error codes.
CmsErrorString(String)
CMS error given as string, because of modem configuration.
There’s probably some way to get modems to report errors as a numeric
error code, so you can make use of the enum. However, I don’t know
of one.
CmsErrorUnknown(u32)
Unknown CMS error code.
NoDialtone
No dialtone.
Busy
Recipient busy.
NoAnswer
No answer.
CommandNotSupported
Command not supported.
TooManyParameters
Too many parameters.
Implementations
Sourceimpl AtResultCode
enum Variant Predicates
impl AtResultCode
enum Variant Predicates
Sourcepub fn is_connect(&self) -> bool
pub fn is_connect(&self) -> bool
Is this AtResultCode a Connect?
Sourcepub fn is_no_carrier(&self) -> bool
pub fn is_no_carrier(&self) -> bool
Is this AtResultCode a NoCarrier?
Sourcepub fn is_cme_error(&self) -> bool
pub fn is_cme_error(&self) -> bool
Is this AtResultCode a CmeError?
Sourcepub fn is_cms_error(&self) -> bool
pub fn is_cms_error(&self) -> bool
Is this AtResultCode a CmsError?
Sourcepub fn is_cms_error_string(&self) -> bool
pub fn is_cms_error_string(&self) -> bool
Is this AtResultCode a CmsErrorString?
Sourcepub fn is_cms_error_unknown(&self) -> bool
pub fn is_cms_error_unknown(&self) -> bool
Is this AtResultCode a CmsErrorUnknown?
Sourcepub fn is_no_dialtone(&self) -> bool
pub fn is_no_dialtone(&self) -> bool
Is this AtResultCode a NoDialtone?
Sourcepub fn is_no_answer(&self) -> bool
pub fn is_no_answer(&self) -> bool
Is this AtResultCode a NoAnswer?
Sourcepub fn is_command_not_supported(&self) -> bool
pub fn is_command_not_supported(&self) -> bool
Is this AtResultCode a CommandNotSupported?
Sourcepub fn is_too_many_parameters(&self) -> bool
pub fn is_too_many_parameters(&self) -> bool
Is this AtResultCode a TooManyParameters?